<?php

namespace Drupal\synmap\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Implements the form controller.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'synmap_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['synmap.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('synmap.settings');

    $form['#attached']['library'][] = 'synmap/synmap.form';
    $form['#attached']['drupalSettings']['synmap']['data'] = [
      'latitude'  => $config->get('map-latitude')?:39.85819697670067,
      'longitude' => $config->get('map-longitude')?:59.21414161964142,
      'zoom'      => $config->get('map-zoom')?:16,
      'name'      => $config->get('yamap-name')?:'Синапс',
      'attach'    => $config->get('yamap-attach'),
      'offset_x'  => $config->get('map-offset_x'),
      'offset_y'  => $config->get('map-offset_y'),
      'editlatitude'  => '#edit-map-latitude',
      'editlongitude' => '#edit-map-longitude',
    ];

    $form['yamap'] = [
      '#type' => 'details',
      '#title' => $this->t('Yandex Map'),
      '#open' => TRUE,
    ];

    $form['yamap']['yamap-name'] = [
      '#title' => $this->t('Company Name'),
      '#default_value' => $config->get('yamap-name'),
      '#maxlength' => 255,
      '#size' => 80,
      '#type' => 'textfield',
      '#description' => $this->t('Что будем писать при клике на пикер?'),
    ];
    $form["yamap"]["yamap-enable"] = array(
      '#title' => t('Enable map'),
      '#type' => 'radios',
      '#options' => array(
        'enable' => t('Whole site enable'),
        'enable_contact' => t('Contact page only'),
        'enable_lp2' => t('LP2 page only'),
        'disable' => t('Disable'),
      ),
      '#default_value' => $config->get('yamap-enable'),
      '#description' => '',
      '#required' => TRUE,
    );
    $form["yamap"]["yamap-path"] = [
      '#title' => t("Attachment page path"),
      '#type' => 'textfield',
      '#default_value' => $config->get('yamap-path'),
      '#description' => t('Example: /contact/feedback'),
    ];
    $form["yamap"]["yamap-attach"] = [
      '#title' => t("Attach to"),
      '#type' => 'textfield',
      '#default_value' => $config->get('yamap-attach'),
      '#description' => t('Map place, example: `.region.region-content`'),
    ];
    // Geoposition.
    $form['geo'] = [
      '#type' => 'details',
      '#title' => $this->t('Yandex Map'),
      '#open' => FALSE,
    ];
    $form["geo"]["map-latitude"] = [
      '#title' => t("Latitude"),
      '#type' => 'textfield',
      '#default_value' => $config->get('map-latitude'),
      '#description' => t('Example: 39.868851844220124'),
    ];
    $form["geo"]["map-longitude"] = [
      '#title' => t("Longitude"),
      '#type' => 'textfield',
      '#default_value' => $config->get('map-longitude'),
      '#description' => t('Example: 59.193704678739856'),
    ];
    $form["geo"]["map-zoom"] = [
      '#title' => t("Zoom"),
      '#type' => 'textfield',
      '#default_value' => $config->get('map-zoom'),
      '#description' => t('Example: 16'),
    ];
    $form["geo"]["map-offset_x"] = [
      '#title' => t("Offset X"),
      '#type' => 'textfield',
      '#default_value' => $config->get('map-offset_x'),
      '#description' => t('Сдвиг центра по горизонтали'),
    ];
    $form["geo"]["map-offset_y"] = [
      '#title' => t("Oddset Y"),
      '#type' => 'textfield',
      '#default_value' => $config->get('map-offset_y'),
      '#description' => t('Сдвиг центра по вертикали'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * Implements a form submit handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('synmap.settings');
    $config
      ->set('yamap-name', $form_state->getValue('yamap-name'))
      ->set('yamap-enable', $form_state->getValue('yamap-enable'))
      ->set('yamap-path', $form_state->getValue('yamap-path'))
      ->set('yamap-attach', $form_state->getValue('yamap-attach'))
      ->set('map-latitude', $form_state->getValue('map-latitude'))
      ->set('map-longitude', $form_state->getValue('map-longitude'))
      ->set('map-zoom', $form_state->getValue('map-zoom'))
      ->set('map-offset_x', $form_state->getValue('map-offset_x'))
      ->set('map-offset_y', $form_state->getValue('map-offset_y'))
      ->save();
  }

}
